@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 """
 This module implements building the ECMWF BUFR library and creation of
 a python interface around the BUFR library provided by
@@ -32,7 +32,7 @@ import tarfile     # handle tar archives
 import shutil      # portable file copying functions
 import subprocess  # support running additional executables
 import stat        # handling of file stat data
-import urllib      # handling of url downloads
+import urllib.request, urllib.parse, urllib.error      # handling of url downloads
 import datetime    # date handling functions
 
 from pybufr_ecmwf.helpers import get_and_set_the_module_path, python3
@@ -88,9 +88,9 @@ CFLAGS_NEEDED = {'gcc': [],
                  'cc':  [],
                  }
 
-for k in FFLAGS_NEEDED.keys():
+for k in list(FFLAGS_NEEDED.keys()):
     FFLAGS_NEEDED[k].extend(FFLAGS_COMMON)
-for k in CFLAGS_NEEDED.keys():
+for k in list(CFLAGS_NEEDED.keys()):
     CFLAGS_NEEDED[k].extend(CFLAGS_COMMON)
 
 # python2 version
@@ -132,7 +132,7 @@ def ensure_permissions(filename, mode):
     if new_mode:
         os.chmod(filename, new_mode)
     else:
-        print('ERROR in ensure_permissions: unknown mode string: ', mode)
+        print(('ERROR in ensure_permissions: unknown mode string: ', mode))
         raise ProgrammingError
     #  #]
 def run_shell_command(cmd, libpath=None, catch_output=True,
@@ -164,7 +164,7 @@ def run_shell_command(cmd, libpath=None, catch_output=True,
         env['PYTHONPATH'] = module_path
 
     if verbose:
-        print("Executing command: ", cmd)
+        print(("Executing command: ", cmd))
 
     if catch_output:
         # print('env[PYTHONPATH] = ', env['PYTHONPATH'])
@@ -220,7 +220,7 @@ def fortran_compile_and_execute(fcmp, fflags, f_code, f_executable, f_libpath):
 
     # now issue the compile command
     if f_libpath == "":
-        print("Executing command: ", cmd)
+        print(("Executing command: ", cmd))
         os.system(cmd)
     else:
         run_shell_command(cmd, libpath=f_libpath, catch_output=False)
@@ -271,11 +271,11 @@ end program pybufr_test_program
                        ' Fortran compilation seems to work fine ...\n']
     if ((expected_output[0] not in lines_stdout) or
         (expected_output[1] not in lines_stdout)):
-        print("ERROR: Fortran compilation test failed; "+
-              "something seems very wrong")
-        print("Expected output: ", expected_output)
-        print('actual output stdout = ', lines_stdout)
-        print('actual output stderr = ', lines_stderr)
+        print(("ERROR: Fortran compilation test failed; "+
+              "something seems very wrong"))
+        print(("Expected output: ", expected_output))
+        print(('actual output stdout = ', lines_stdout))
+        print(('actual output stderr = ', lines_stderr))
         raise EnvironmentError
 
     print("Fortran compilation test successfull...")
@@ -303,7 +303,7 @@ def c_compile_and_execute(ccmp, cflags, c_code, c_executable, c_libpath):
 
     # now issue the compile command
     if c_libpath == "":
-        print("Executing command: ", cmd)
+        print(("Executing command: ", cmd))
         os.system(cmd)
     else:
         run_shell_command(cmd, libpath=c_libpath, catch_output=False)
@@ -350,9 +350,9 @@ int main()
     if ((expected_output[0] not in lines_stdout) or
         (expected_output[1] not in lines_stdout)):
         print("ERROR: c compilation test failed; something seems very wrong")
-        print("Expected output: ", expected_output)
-        print('actual output stdout = ', lines_stdout)
-        print('actual output stderr = ', lines_stderr)
+        print(("Expected output: ", expected_output))
+        print(('actual output stdout = ', lines_stdout))
+        print(('actual output stderr = ', lines_stderr))
         raise EnvironmentError
 
     print("c compilation test successfull...")
@@ -467,7 +467,7 @@ def insert_pb_interface_definition(sfd, integer_sizes):
     #    intlen = ByteSizeLong # = 8 bytes
 
     intlen = bytesizelong # = 8 bytes
-    print('Using intlen = ', intlen, ' to build the pbio interface')
+    print(('Using intlen = ', intlen, ' to build the pbio interface'))
 
     indentation = 8*' '
     lines_to_add = \
@@ -508,8 +508,8 @@ def insert_pb_interface_definition(sfd, integer_sizes):
           "end subroutine pbseek",
           ]
 
-    print("Inserting hardcoded interface to pbio routines in "+
-          "signatures file ...")
+    print(("Inserting hardcoded interface to pbio routines in "+
+          "signatures file ..."))
     for lta in lines_to_add:
         sfd.write(indentation+lta+'\n')
 
@@ -643,7 +643,7 @@ def adapt_f2py_signature_file(signature_file, integer_sizes):
 
         if 'dimension' in mod_line:
             #print("adapting line: ", mod_line)
-            for edit in edits.keys():
+            for edit in list(edits.keys()):
                 txt = '(('+edit.lower()+'))'
                 value = edits[edit]
                 if txt in mod_line:
@@ -860,9 +860,9 @@ class InstallBUFRInterfaceECMWF(object):
             wrapper_was_build = True
 
         if (not bufr_was_build) and (not wrapper_was_build):
-            print("\nNothing to do\n"+
+            print(("\nNothing to do\n"+
                   "Execute the clean.py tool if you wish to start again "+
-                  "from scratch.")
+                  "from scratch."))
 
         print('extracting library constants')
         self.extract_constants()
@@ -895,7 +895,7 @@ class InstallBUFRInterfaceECMWF(object):
         for dir_to_remove in dirs_to_remove:
             if os.path.exists(dir_to_remove):
                 cmd = r'\rm -rf '+dir_to_remove
-                print("executing command: ", cmd)
+                print(("executing command: ", cmd))
                 os.system(cmd)
         #  #]
     def find_copy_of_library(self):
@@ -942,7 +942,7 @@ class InstallBUFRInterfaceECMWF(object):
                     # print("list_of_bufr_tarfiles = ", list_of_bufr_tarfiles)
                     for btf in list_of_bufr_tarfiles:
                         bbtf = os.path.split(btf)[1]
-                        print("making symlink from [%s] to [%s]" % (btf, bbtf))
+                        print(("making symlink from [%s] to [%s]" % (btf, bbtf)))
                         os.symlink(btf, bbtf)
                     break # exit the while loop
 
@@ -974,7 +974,7 @@ class InstallBUFRInterfaceECMWF(object):
                     tgz_file = tgz_filelist[0]
 
                     cmd = 'cp '+tgz_file+' '+self.ecmwf_bufr_lib_dir
-                    print("Executing command: ", cmd)
+                    print(("Executing command: ", cmd))
                     os.system(cmd)
                     break
 
@@ -997,10 +997,10 @@ class InstallBUFRInterfaceECMWF(object):
             print("setting up connection to ECMWF website")
         try:
             # Get a file-like object for this website
-            urlf = urllib.urlopen(URL_BUFR_PAGE)
+            urlf = urllib.request.urlopen(URL_BUFR_PAGE)
         except IOError:
             print("connection failed......")
-            print("could not open url: ", URL_BUFR_PAGE)
+            print(("could not open url: ", URL_BUFR_PAGE))
             return (None, None)
 
         # Read from the object, storing the page's contents in a list of lines
@@ -1066,8 +1066,8 @@ class InstallBUFRInterfaceECMWF(object):
 
         # report the result
         if self.verbose:
-            print("Most recent library version seems to be: ",
-                  most_recent_bufr_tarfile_name)
+            print(("Most recent library version seems to be: ",
+                  most_recent_bufr_tarfile_name))
 
         return (most_recent_bufr_lib_url,
                 most_recent_bufr_tarfile_name)
@@ -1086,15 +1086,15 @@ class InstallBUFRInterfaceECMWF(object):
         #return False
 
         if self.verbose:
-            print("trying to download: ", most_recent_bufr_tarfile_name)
+            print(("trying to download: ", most_recent_bufr_tarfile_name))
 
         download_url = URL_ECMWF_WEBSITE+most_recent_bufr_lib_url
         try:
             # Get a file-like object for this website
-            urlf = urllib.urlopen(download_url)
+            urlf = urllib.request.urlopen(download_url)
         except IOError:
             print("connection failed......")
-            print("could not open url: ", download_url)
+            print(("could not open url: ", download_url))
             return False
 
         tarfiledata = urlf.read()
@@ -1109,7 +1109,7 @@ class InstallBUFRInterfaceECMWF(object):
         tfd.close()
 
         if self.verbose:
-            print("created local copy of: ", most_recent_bufr_tarfile_name)
+            print(("created local copy of: ", most_recent_bufr_tarfile_name))
 
         return True
         #  #]
@@ -1131,8 +1131,8 @@ class InstallBUFRInterfaceECMWF(object):
         # sort in reverse alphabetical order to get the newest one on top
         list_of_bufr_tarfiles.sort(reverse=True)
         if self.verbose:
-            print("available library tarfiles: ", list_of_bufr_tarfiles)
-            print("most recent library tarfile: ", list_of_bufr_tarfiles[0])
+            print(("available library tarfiles: ", list_of_bufr_tarfiles))
+            print(("most recent library tarfile: ", list_of_bufr_tarfiles[0]))
 
         tarfile_to_install = os.path.split(list_of_bufr_tarfiles[0])[1]
 
@@ -1210,10 +1210,10 @@ class InstallBUFRInterfaceECMWF(object):
 
                 cmd = "cd "+self.ecmwf_bufr_lib_dir+\
                       ";tar zxvf "+tarfile_to_install
-                print("Executing command: ", cmd)
+                print(("Executing command: ", cmd))
                 os.system(cmd)
             else:
-                print("path exists: ", source_dir)
+                print(("path exists: ", source_dir))
                 print("assuming the package is already unpacked...")
 
             # extract numerical BUFR library version
@@ -1248,7 +1248,7 @@ class InstallBUFRInterfaceECMWF(object):
             for fortr_file in additional_fortran_files:
                 shutil.copy(os.path.join(add_fortran_dir, fortr_file),
                             os.path.join(source_dir, 'bufrdc', fortr_file))
-                print('copied file: '+fortr_file)
+                print(('copied file: '+fortr_file))
 
             # add these new source files to the sources list to include it in
             # the compilation and library creation procedure
@@ -1265,7 +1265,7 @@ class InstallBUFRInterfaceECMWF(object):
             fds.write(''.join(line for line in sources_lines[:5]))
             for fortr_file in additional_fortran_files:
                 fds.write('   '+fortr_file+' \\\n')
-                print('added file '+fortr_file+' to the sources list')
+                print(('added file '+fortr_file+' to the sources list'))
             fds.write(''.join(line for line in sources_lines[5:]))
             fds.close()
             #  #]
@@ -1274,9 +1274,9 @@ class InstallBUFRInterfaceECMWF(object):
 
         #if (self.verbose):
         print('selection fortran compiler')
-        print('==>input: self.fortran_compiler = ', self.fortran_compiler)
-        print('==>input: self.preferred_fortran_compiler = ',
-              self.preferred_fortran_compiler)
+        print(('==>input: self.fortran_compiler = ', self.fortran_compiler))
+        print(('==>input: self.preferred_fortran_compiler = ',
+              self.preferred_fortran_compiler))
 
         # first check a possible custom executable, passed in
         # through the setup.cfg file or on the commandline
@@ -1296,16 +1296,16 @@ class InstallBUFRInterfaceECMWF(object):
             if self.preferred_fortran_compiler is not None:
                 if not (self.preferred_fortran_compiler in
                         POSSIBLE_F_COMPILERS):
-                    print("ERROR: unknown preferred fortran compiler "+
+                    print(("ERROR: unknown preferred fortran compiler "+
                           "specified:",
-                          self.preferred_fortran_compiler)
-                    print("valid options are: ",
-                          ", ".join(s for s in POSSIBLE_F_COMPILERS))
+                          self.preferred_fortran_compiler))
+                    print(("valid options are: ",
+                          ", ".join(s for s in POSSIBLE_F_COMPILERS)))
                     raise NotImplementedError
 
-            print("preferred fortran compiler ["+
+            print(("preferred fortran compiler ["+
                   str(self.preferred_fortran_compiler)+
-                  "] seems not available...")
+                  "] seems not available..."))
             print("falling back to default fortran compiler")
 
             for f_compiler in POSSIBLE_F_COMPILERS:
@@ -1326,8 +1326,8 @@ class InstallBUFRInterfaceECMWF(object):
 
         #if (self.verbose):
         print('selection fortran compiler')
-        print('==>result: self.fortran_compiler_to_use = ',
-              self.fortran_compiler_to_use)
+        print(('==>result: self.fortran_compiler_to_use = ',
+              self.fortran_compiler_to_use))
 
         #  #]
 
@@ -1335,9 +1335,9 @@ class InstallBUFRInterfaceECMWF(object):
 
         #if (self.verbose):
         print('selection c compiler')
-        print('==>input: self.c_compiler = ', self.c_compiler)
-        print('==>input: self.preferred_c_compiler = ',
-              self.preferred_c_compiler)
+        print(('==>input: self.c_compiler = ', self.c_compiler))
+        print(('==>input: self.preferred_c_compiler = ',
+              self.preferred_c_compiler))
 
         # first check a possible custom executable, passed in
         # through the setup.cfg file or on the commandline
@@ -1356,19 +1356,19 @@ class InstallBUFRInterfaceECMWF(object):
             # a sanity check
             if self.preferred_c_compiler is not None:
                 if not (self.preferred_c_compiler in POSSIBLE_C_COMPILERS):
-                    print("ERROR: unknown preferred c compiler "+
+                    print(("ERROR: unknown preferred c compiler "+
                           "specified:",
-                          self.preferred_c_compiler)
-                    print("valid options are: ",
-                          ", ".join(s for s in POSSIBLE_C_COMPILERS))
+                          self.preferred_c_compiler))
+                    print(("valid options are: ",
+                          ", ".join(s for s in POSSIBLE_C_COMPILERS)))
                     raise NotImplementedError
 
             if self.preferred_c_compiler is None:
                 print("no preferred c compiler given")
             else:
-                print("preferred c compiler ["+
+                print(("preferred c compiler ["+
                       str(self.preferred_c_compiler)+
-                      "] seems not available...")
+                      "] seems not available..."))
             print("falling back to default c compiler")
 
             for c_compiler in POSSIBLE_C_COMPILERS:
@@ -1388,7 +1388,7 @@ class InstallBUFRInterfaceECMWF(object):
 
         #if (self.verbose):
         print('selection c compiler')
-        print('==>result: self.c_compiler_to_use = ', self.c_compiler_to_use)
+        print(('==>result: self.c_compiler_to_use = ', self.c_compiler_to_use))
 
         #  #]
 
@@ -1404,7 +1404,7 @@ class InstallBUFRInterfaceECMWF(object):
                                if s != "")
 
         if libpath != "":
-            print("Using LD_LIBRARY_PATH setting: ", libpath)
+            print(("Using LD_LIBRARY_PATH setting: ", libpath))
         #  #]
 
         if not remake:
@@ -1528,10 +1528,10 @@ class InstallBUFRInterfaceECMWF(object):
             #        os.symlink(config_file+".in", fullname_config_file)
 
             # create our custom config file:
-            print("Using: "+fcmp+" as fortran compiler")
-            print("Using: "+ccmp+" as c compiler")
+            print(("Using: "+fcmp+" as fortran compiler"))
+            print(("Using: "+ccmp+" as c compiler"))
 
-            print("Creating ECMWF-BUFR config file: ", fullname_config_file)
+            print(("Creating ECMWF-BUFR config file: ", fullname_config_file))
             cfd = open(fullname_config_file, 'w')
             cfd.write("#   Generic configuration file for linux.\n")
             cfd.write("AR         = "+arcmd+"\n")
@@ -1613,7 +1613,7 @@ class InstallBUFRInterfaceECMWF(object):
                 makefile = os.path.join(source_dir, makefile_dir, 'Makefile')
                 makefile_template = makefile+'.in'
                 if os.path.exists(makefile_template):
-                    print('creating: ', makefile)
+                    print(('creating: ', makefile))
                     fd_makefile = open(makefile, 'w')
                     for line in open(makefile_template).readlines():
                         line_new = line
@@ -1642,7 +1642,7 @@ class InstallBUFRInterfaceECMWF(object):
 
         # now issue the Make command
         if libpath == "":
-            print("Executing command: ", cmd)
+            print(("Executing command: ", cmd))
             os.system(cmd)
         else:
             #(lines_stdout, lines_stderr) = \
@@ -1753,7 +1753,7 @@ class InstallBUFRInterfaceECMWF(object):
         from a user shell (using the which command) """
 
         if self.verbose:
-            print("checking for presence of command: "+str(command))
+            print(("checking for presence of command: "+str(command)))
 
         if command == None:
             return False
@@ -1821,12 +1821,12 @@ class InstallBUFRInterfaceECMWF(object):
                       " "+source_file_list
 
             if libpath == "":
-                print("Executing command: ", cmd)
+                print(("Executing command: ", cmd))
                 os.system(cmd)
                 # (lines_stdout, lines_stderr) = \
                 #       run_shell_command(cmd, catch_output = True)
             else:
-                print("Using LD_LIBRARY_PATH setting: ", libpath)
+                print(("Using LD_LIBRARY_PATH setting: ", libpath))
                 # (lines_stdout, lines_stderr) = \
                 #       run_shell_command(cmd, libpath = libpath,
                 #                              catch_output = True)
@@ -1882,7 +1882,7 @@ class InstallBUFRInterfaceECMWF(object):
                   " ./f2py_build/signatures.pyf -L./ -lbufr -c"
 
         if libpath == "":
-            print("Executing command: ", cmd)
+            print(("Executing command: ", cmd))
             os.system(cmd)
             #(lines_stdout, lines_stderr) = \
             #       run_shell_command(cmd, catch_output = False)
@@ -1902,8 +1902,8 @@ class InstallBUFRInterfaceECMWF(object):
             wrapper_name = 'undefined'
 
         if os.path.exists(wrapper_name):
-            print("a python wrapper to the ECMWF BUFR library "+
-                  "has been generated")
+            print(("a python wrapper to the ECMWF BUFR library "+
+                  "has been generated"))
             return
         else:
             print("ERROR: build of python wrapper failed")
@@ -1940,7 +1940,7 @@ class InstallBUFRInterfaceECMWF(object):
             parameter_dict[key] = constants[i]
 
         python_parameter_file = 'ecmwfbufr_parameters.py'
-        print('creating parameter python file: ', python_parameter_file)
+        print(('creating parameter python file: ', python_parameter_file))
         pfd = open(python_parameter_file, 'w')
 
         # write a simple doc string
@@ -1957,7 +1957,7 @@ file for convenience
         pfd.write('"""\n')
 
         # write the retrieved parameter values to a python file
-        for (key, val) in parameter_dict.iteritems():
+        for (key, val) in parameter_dict.items():
             txt = key+' = '+str(val)+'\n'
             pfd.write(txt)
 
@@ -2065,9 +2065,9 @@ if __name__ == "__main__":
         SO_WRAPPER_NAME = 'undefined'
 
     if os.path.exists(SO_WRAPPER_NAME):
-        print("successfully build:", SO_WRAPPER_NAME)
+        print(("successfully build:", SO_WRAPPER_NAME))
     else:
-        print("cannot find a file with pattern:", SO_FILE_PATTERN)
+        print(("cannot find a file with pattern:", SO_FILE_PATTERN))
         print("something seems wrong here ...")
         raise InterfaceBuildError
     #  #]
