@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
 """ a script to automatically try and verify the different
 build options with the on the current system available
@@ -54,7 +54,7 @@ def run_shell_command(cmd_to_run, sp_env=None):
 #  #]
 #  #[ init
 if not os.path.exists(REPODIR):
-    print('ERROR: could not find REPODIR: '+REPODIR)
+    print(('ERROR: could not find REPODIR: '+REPODIR))
     sys.exit(1)
 
 if not os.path.exists(TESTDIR):
@@ -71,8 +71,8 @@ for fc in POSSIBLE_FORTRAN_COMPILERS:
     if len(lines_stderr) == 0:
         AVAILABLE_POSSIBLE_COMPILERS.append(fc)
 
-print('available fortran compilers: ',
-      ', '.join(fc for fc in AVAILABLE_POSSIBLE_COMPILERS))
+print(('available fortran compilers: ',
+      ', '.join(fc for fc in AVAILABLE_POSSIBLE_COMPILERS)))
 #  #]
 TESTRESULTS = []
 for fc in AVAILABLE_POSSIBLE_COMPILERS:
@@ -82,7 +82,7 @@ for fc in AVAILABLE_POSSIBLE_COMPILERS:
         build_dir_name = 'manual_build_'+fc
         temp_build_dir = os.path.join(TESTDIR, build_dir_name)
         if os.path.exists(temp_build_dir):
-            print('dir: ', temp_build_dir, ' exists; removing it first')
+            print(('dir: ', temp_build_dir, ' exists; removing it first'))
             cmd = '\\rm -rf '+temp_build_dir
             os.system(cmd)
 
@@ -92,15 +92,15 @@ for fc in AVAILABLE_POSSIBLE_COMPILERS:
 
         # -clone the repository
         cmd = 'cd '+TESTDIR+'; hg clone '+REPODIR+' '+build_dir_name
-        print("Executing command: ", cmd)
+        print(("Executing command: ", cmd))
         os.system(cmd)
 
         # step into the test dir
         saved_cwd = os.getcwd()
         os.chdir(temp_build_dir)
 
-        print('saved_cwd   = ', saved_cwd)
-        print('os.getcwd() = ', os.getcwd())
+        print(('saved_cwd   = ', saved_cwd))
+        print(('os.getcwd() = ', os.getcwd()))
 
         # -build the software
         sys.path.append(os.getcwd())
@@ -160,13 +160,13 @@ for fc in AVAILABLE_POSSIBLE_COMPILERS:
         build_dir_name = 'build_'+fc
         temp_build_dir = os.path.join(TESTDIR, build_dir_name)
         if os.path.exists(temp_build_dir):
-            print('dir: ', temp_build_dir, ' exists; removing it first')
+            print(('dir: ', temp_build_dir, ' exists; removing it first'))
             cmd = '\\rm -rf '+temp_build_dir
             os.system(cmd)
 
         # -clone the repository
         cmd = 'cd '+TESTDIR+'; hg clone '+REPODIR+' '+build_dir_name
-        print("Executing command: ", cmd)
+        print(("Executing command: ", cmd))
         os.system(cmd)
 
         # -edit the setup.cfg file to choose the compiler
@@ -234,13 +234,13 @@ for fc in AVAILABLE_POSSIBLE_COMPILERS:
         build_dir_name = 'build_sdist_'+fc
         temp_build_dir = os.path.join(TESTDIR, build_dir_name)
         if os.path.exists(temp_build_dir):
-            print('dir: ', temp_build_dir, ' exists; removing it first')
+            print(('dir: ', temp_build_dir, ' exists; removing it first'))
             cmd = '\\rm -rf '+temp_build_dir
             os.system(cmd)
 
         # -clone the repository
         cmd = 'cd '+TESTDIR+'; hg clone '+REPODIR+' '+build_dir_name
-        print("Executing command: ", cmd)
+        print(("Executing command: ", cmd))
         os.system(cmd)
 
         # -edit the setup.cfg file to choose the compiler
@@ -354,13 +354,13 @@ for fc in AVAILABLE_POSSIBLE_COMPILERS:
         build_dir_name = 'build_pip_'+fc
         temp_build_dir = os.path.join(TESTDIR, build_dir_name)
         if os.path.exists(temp_build_dir):
-            print('dir: ', temp_build_dir, ' exists; removing it first')
+            print(('dir: ', temp_build_dir, ' exists; removing it first'))
             cmd = '\\rm -rf '+temp_build_dir
             os.system(cmd)
 
         # -clone the repository
         cmd = 'cd '+TESTDIR+'; hg clone '+REPODIR+' '+build_dir_name
-        print("Executing command: ", cmd)
+        print(("Executing command: ", cmd))
         os.system(cmd)
 
         # -edit the setup.cfg file to choose the compiler
@@ -424,7 +424,7 @@ for fc in AVAILABLE_POSSIBLE_COMPILERS:
                 'rm -rf myenv/']
 
         cmd = ';'.join(c for c in cmds)
-        print('executing cmd: [{}]'.format(cmd))
+        print(('executing cmd: [{}]'.format(cmd)))
         (lines_stdout, lines_stderr) = run_shell_command(cmd)
 
         # -verify the output
@@ -447,7 +447,7 @@ for fc in AVAILABLE_POSSIBLE_COMPILERS:
         build_dir_name = 'py3_manual_build_'+fc
         temp_build_dir = os.path.join(TESTDIR, build_dir_name)
         if os.path.exists(temp_build_dir):
-            print('dir: ', temp_build_dir, ' exists; removing it first')
+            print(('dir: ', temp_build_dir, ' exists; removing it first'))
             cmd = '\\rm -rf '+temp_build_dir
             os.system(cmd)
 
@@ -457,28 +457,28 @@ for fc in AVAILABLE_POSSIBLE_COMPILERS:
 
         # -clone the repository
         cmd = 'cd '+TESTDIR+'; hg clone '+REPODIR+' '+build_dir_name
-        print("Executing command: ", cmd)
+        print(("Executing command: ", cmd))
         os.system(cmd)
 
         # step into the test dir
         saved_cwd = os.getcwd()
         os.chdir(temp_build_dir)
 
-        print('temp_build_dir = ', temp_build_dir)
-        print('saved_cwd   = ', saved_cwd)
-        print('os.getcwd() = ', os.getcwd())
+        print(('temp_build_dir = ', temp_build_dir))
+        print(('saved_cwd   = ', saved_cwd))
+        print(('os.getcwd() = ', os.getcwd()))
 
         # convert the source code to python3
         cmd = './port_2to3.py'
-        print("Executing command: ", cmd)
+        print(("Executing command: ", cmd))
         os.system(cmd)
 
         temp_py3_build_dir = 'tmp_2to3_converted_sources'
 
         os.chdir(temp_py3_build_dir)
 
-        print('temp_py3_build_dir = ', temp_py3_build_dir)
-        print('os.getcwd() = ', os.getcwd())
+        print(('temp_py3_build_dir = ', temp_py3_build_dir))
+        print(('os.getcwd() = ', os.getcwd()))
 
         # -build the software
         sys.path.append(os.getcwd())
@@ -583,10 +583,10 @@ for fc in AVAILABLE_POSSIBLE_COMPILERS:
 
         #  #]
 
-print(50*'=')
+print((50*'='))
 for result in TESTRESULTS:
     #  #[ display the results
     for l in result:
         print(l)
-    print(50*'=')
+    print((50*'='))
     #  #]
