@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
 '''a simple example script showing how to retrieve a description name
 from a descroptor code.'''
@@ -10,5 +10,5 @@ BTABLE = 'pybufr_ecmwf/ecmwf_bufrtables/B2550000000098006001.TXT'
 BT.load(BTABLE)
 
 OBJ = BT.get_descr_object(int('001001', 10))
-print 'OBJ: ', OBJ
-print 'OBJ.name: ', OBJ.name
+print('OBJ: ', OBJ)
+print('OBJ.name: ', OBJ.name)
