@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
 '''
 a simple script to loop over bufr files as provided in the ecmwf bufr library
@@ -12,6 +12,6 @@ and show the bufr edition numbers for them.
 import os, glob
 for f in glob.glob('pybufr_ecmwf/ecmwf_bufr_lib/000401/data/*.bufr'):
     cmd = 'example_programs/bufr_extract_edition.py '+f
-    print f
+    print(f)
     os.system(cmd)
 
