@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
 """
 This file defines the RawBUFRFile class, an alternative for
@@ -64,17 +64,17 @@ class RawBUFRFile:
         # different addresses each time, and is not so very interesting
         # to print, so leave it out for now
         #print(prefix+": bufr_fd  = ", self.bufr_fd)
-        print(prefix+": filename = {}".format(self.filename))
-        print(prefix+": filemode = {}".format(self.filemode))
-        print(prefix+": filesize = {}".format(self.filesize))
+        print((prefix+": filename = {}".format(self.filename)))
+        print((prefix+": filemode = {}".format(self.filemode)))
+        print((prefix+": filesize = {}".format(self.filesize)))
         if (self.data != None):
-            print(prefix+": len(data) = {}".format(len(self.data)))
+            print((prefix+": len(data) = {}".format(len(self.data))))
         else:
-            print(prefix+": data = {}".format(self.data))
-        print(prefix+": list_of_bufr_pointers = {}".
-              format(self.list_of_bufr_pointers))
-        print(prefix+": nr_of_bufr_messages = {}".
-              format(self.nr_of_bufr_messages))
+            print((prefix+": data = {}".format(self.data)))
+        print((prefix+": list_of_bufr_pointers = {}".
+              format(self.list_of_bufr_pointers)))
+        print((prefix+": nr_of_bufr_messages = {}".
+              format(self.nr_of_bufr_messages)))
         #  #]
     def open(self, filename, mode, silent = False):
         #  #[
@@ -97,8 +97,8 @@ class RawBUFRFile:
             else:
                 if (not silent):
                     print("ERROR in BUFRFile.open():")
-                    print("Opening file: ", self.filename, " with mode: ",
-                          self.filemode, " failed")
+                    print(("Opening file: ", self.filename, " with mode: ",
+                          self.filemode, " failed"))
                     print("This file was not found or is not accessible.")
                 raise IOError
         elif (mode == 'wb'):
@@ -134,8 +134,8 @@ class RawBUFRFile:
         except:
             if (not silent):
                 print("ERROR in BUFRFile.open():")
-                print("Opening file: ", self.filename, " with mode: ",
-                      self.filemode, " failed")
+                print(("Opening file: ", self.filename, " with mode: ",
+                      self.filemode, " failed"))
             raise IOError
 
         if (mode == 'rb'):
@@ -144,8 +144,8 @@ class RawBUFRFile:
             except:
                 if (not silent):
                     print("ERROR in BUFRFile.open():")
-                    print("Reading data from file: ", self.filename,
-                          " with mode: ", self.filemode, " failed")
+                    print(("Reading data from file: ", self.filename,
+                          " with mode: ", self.filemode, " failed"))
                 raise IOError
 
             # split in separate BUFR messages
@@ -206,13 +206,13 @@ class RawBUFRFile:
 
         # self.verbose = True
         if (self.verbose):
-            print('getting size of BUFR message at start location: ',
-                  start_location)
+            print(('getting size of BUFR message at start location: ',
+                  start_location))
         try:
             raw_edition_number = self.data[start_location+8-1:start_location+8]
             edition_number = ord(raw_edition_number)
             if (self.verbose):
-                print('edition_number = ', edition_number)
+                print(('edition_number = ', edition_number))
         except IndexError:
              # 0 signals this is not a valid BUFR msg, might be a false
              # start BUFR string, or a corrupted or truncated file
@@ -254,9 +254,9 @@ class RawBUFRFile:
                 # AND the BUFR msg size (3 bytes) and the BUFR edition nr.
 
             if (self.verbose):
-                print('size_section0 = ', size_section0,
+                print(('size_section0 = ', size_section0,
                       'start_section0 = ', start_section0,
-                      '[', hex(start_section0), ']')
+                      '[', hex(start_section0), ']'))
             #  #]
             #  #[ retrieve size of section 1
             offset = size_section0
@@ -272,9 +272,9 @@ class RawBUFRFile:
                 return (0, section_sizes, section_start_locations)
 
             if (self.verbose):
-                print('size_section1 = ', size_section1,
+                print(('size_section1 = ', size_section1,
                       ' start_section1 = ', start_section1,
-                      '[', hex(start_section1), ']')
+                      '[', hex(start_section1), ']'))
             #  #]
             #  #[ retrieve size of section 2
             
@@ -335,9 +335,9 @@ class RawBUFRFile:
                 size_section2 = 0
 
             if (self.verbose):
-                print('size_section2 = ',size_section2,
+                print(('size_section2 = ',size_section2,
                       ' start_section2 = ', start_section2,
-                      '[', hex(start_section2), ']')
+                      '[', hex(start_section2), ']'))
             #  #]
             #  #[ retrieve size of section 3
             offset = size_section0 + size_section1 + size_section2
@@ -353,9 +353,9 @@ class RawBUFRFile:
                 return (0, section_sizes, section_start_locations)
 
             if (self.verbose):
-                print('size_section3 = ',size_section3,
+                print(('size_section3 = ',size_section3,
                       ' start_section3 = ', start_section3,
-                      '[', hex(start_section3), ']')
+                      '[', hex(start_section3), ']'))
             #  #]
             #  #[ retrieve size of section 4
             offset = size_section0 + size_section1 + \
@@ -380,9 +380,9 @@ class RawBUFRFile:
                 return (0, section_sizes, section_start_locations)
 
             if (self.verbose):
-                print('size_section4 = ',size_section4,
+                print(('size_section4 = ',size_section4,
                       ' start_section4 = ', start_section4,
-                      '[', hex(start_section4), ']')
+                      '[', hex(start_section4), ']'))
             #  #]
             #  #[ retrieve size of section 5
             offset = size_section0 + size_section1 + \
@@ -392,8 +392,8 @@ class RawBUFRFile:
             size_section5 = 4
 
             if (self.verbose):
-                print('size_section5 = ',size_section5,
-                      ' start_section5 = ', start_section5)
+                print(('size_section5 = ',size_section5,
+                      ' start_section5 = ', start_section5))
             #  #]
             calculated_msg_size = size_section0 + size_section1 + \
                                   size_section2 + size_section3 + \
@@ -407,10 +407,10 @@ class RawBUFRFile:
                 # extra sanity check
                 if msg_size != calculated_msg_size:
                     print('ERROR! msg_size from section0 does not match')
-                    print('msg_size calculated from individual '+
-                          'section lengths!')
-                    print('msg_size from section0: ',msg_size)
-                    print('calculated msg_size;    ',calculated_msg_size)
+                    print(('msg_size calculated from individual '+
+                          'section lengths!'))
+                    print(('msg_size from section0: ',msg_size))
+                    print(('calculated msg_size;    ',calculated_msg_size))
                     print('SKIPPING this message...')
                     return (0, section_sizes, section_start_locations)
                 
@@ -442,9 +442,9 @@ class RawBUFRFile:
 
         if self.warn_about_bufr_size:
             if msg_size > 500000:
-                print("WARNING: by convention BUFR messages should not be "+
+                print(("WARNING: by convention BUFR messages should not be "+
                       "larger than 500kb to allow transmission over the GTS. "+
-                      "Size of current message is: ", msg_size, " bytes")
+                      "Size of current message is: ", msg_size, " bytes"))
 
         return (msg_size, section_sizes, section_start_locations)
         #  #]        
@@ -511,7 +511,7 @@ class RawBUFRFile:
             expected_msg_size, section_sizes, section_start_locations = \
                                self.get_expected_msg_size(start_location)
             if (self.verbose):
-                print('expected_msg_size = ', expected_msg_size)
+                print(('expected_msg_size = ', expected_msg_size))
             expected_msg_end_location = start_location + expected_msg_size - 4
             if expected_msg_end_location in list_of_end_locations:
                 if (self.verbose):
@@ -530,8 +530,8 @@ class RawBUFRFile:
         self.nr_of_bufr_messages = len(self.list_of_bufr_pointers)
 
         if (self.verbose):
-            print("list_of_start_locations = ", list_of_start_locations)
-            print("list_of_end_locations   = ", list_of_end_locations)
+            print(("list_of_start_locations = ", list_of_start_locations))
+            print(("list_of_end_locations   = ", list_of_end_locations))
 
         #  #]
     def get_num_bufr_msgs(self):
@@ -561,15 +561,15 @@ class RawBUFRFile:
 
         # sanity test
         if (msg_nr>self.nr_of_bufr_messages):
-            print("WARNING: non-existing BUFR message: ", msg_nr)
-            print("This file only contains: ", self.nr_of_bufr_messages,
-                  " BUFR messages")
+            print(("WARNING: non-existing BUFR message: ", msg_nr))
+            print(("This file only contains: ", self.nr_of_bufr_messages,
+                  " BUFR messages"))
             return (None, None, None)
 
         if (msg_nr<1):
-            print("WARNING: invalid BUFR message number: ", msg_nr)
-            print("For this file this number should be between 1 and: ",
-                  self.nr_of_bufr_messages)
+            print(("WARNING: invalid BUFR message number: ", msg_nr))
+            print(("For this file this number should be between 1 and: ",
+                  self.nr_of_bufr_messages))
             return (None, None, None)
 
         self.last_used_msg = msg_nr
@@ -586,10 +586,10 @@ class RawBUFRFile:
         padding_bytes = size_words*4-size_bytes
 
         if (self.verbose):
-            print("size_bytes = ", size_bytes)
-            print("size_words = ", size_words)
-            print("size_words*4 = ", size_words*4)
-            print("padding_bytes = ", padding_bytes)
+            print(("size_bytes = ", size_bytes))
+            print(("size_words = ", size_words))
+            print(("size_words*4 = ", size_words*4))
+            print(("padding_bytes = ", padding_bytes))
             
         # make sure we take the padding bytes along
         end_index = end_index+padding_bytes
@@ -615,7 +615,7 @@ class RawBUFRFile:
             raw_data_bytes = raw_data_bytes + str_to_add
 
         if (self.verbose):
-            print("len(raw_data_bytes) = ", len(raw_data_bytes))
+            print(("len(raw_data_bytes) = ", len(raw_data_bytes)))
 
         # assume little endian for now when converting
         # raw bytes/characters to integers and vice-versa
@@ -650,8 +650,8 @@ class RawBUFRFile:
         size_words = len(words)
         size_bytes = size_words*4
         if (self.verbose):
-            print("size_bytes = ", size_bytes)
-            print("size_words = ", size_words)
+            print(("size_bytes = ", size_bytes))
+            print(("size_words = ", size_words))
 
         # convert the words to bytes in a string and write them to file
 
@@ -673,12 +673,12 @@ class RawBUFRFile:
 
             if i == 0:
                 if (self.verbose):
-                    print("word = ", word)
-                    print('data = ', data)
-                    print('data[:4] = ', data[:4])
-                    print('data[:4] = ', ';'.join(str(data[j])
+                    print(("word = ", word))
+                    print(('data = ', data))
+                    print(('data[:4] = ', data[:4]))
+                    print(('data[:4] = ', ';'.join(str(data[j])
                                                   for j in range(4)
-                                                  if data[j].isalnum()))
+                                                  if data[j].isalnum())))
                 # safety check
                 assert(data[:4] == b'BUFR')
 
