@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 """
 a module to execute unittests on all important pieces
 of code in this module.
@@ -239,7 +239,7 @@ def call_cmd_and_verify_output(cmd, rundir=''):
         if not (lines_stdout == expected_lines_stdout):
             print("stdout differs from what was expected!!!")
             print("to find out what happended execute this diff command:")
-            print("xdiff "+actual_stdout+' '+expected_stdout)
+            print(("xdiff "+actual_stdout+' '+expected_stdout))
             # for l in lines_stdout:          print('output:      ['+l+']')
             # for l in expected_lines_stdout: print('exp. output: ['+l+']')
             success = False
@@ -247,18 +247,18 @@ def call_cmd_and_verify_output(cmd, rundir=''):
         if not (lines_stderr == expected_lines_stderr):
             print("stderr differs from what was expected!!!")
             print("to find out what happended execute this diff command:")
-            print("xdiff "+actual_stderr+' '+expected_stderr)
+            print(("xdiff "+actual_stderr+' '+expected_stderr))
             success = False
     except IOError:
         print("ERROR: expected output not found; probably because")
         print("you just defined a new unittest case.")
         print("Missing filenames:")
         if not os.path.exists(expected_stdout):
-            print("expected_stdout: ", expected_stdout)
-            print("(actual output available in: ", actual_stdout, ")")
+            print(("expected_stdout: ", expected_stdout))
+            print(("(actual output available in: ", actual_stdout, ")"))
         if not os.path.exists(expected_stderr):
-            print("expected_stderr: ", expected_stderr)
-            print("(actual output available in: ", actual_stderr, ")")
+            print(("expected_stderr: ", expected_stderr))
+            print(("(actual output available in: ", actual_stderr, ")"))
         success = False
 
     return success
@@ -594,7 +594,7 @@ class CheckRawBUFRFile(unittest.TestCase):
         testfile = "tmp_testfile.read.BUFR"
         if os.path.exists(testfile):
             # force the file to be readwrite
-            os.chmod(testfile, 0666)
+            os.chmod(testfile, 0o666)
             os.remove(testfile)
 
         # create a small dummy file
@@ -609,14 +609,14 @@ class CheckRawBUFRFile(unittest.TestCase):
         # cleanup
         if os.path.exists(testfile):
             # force the file to be readwrite
-            os.chmod(testfile, 0666)
+            os.chmod(testfile, 0o666)
             os.remove(testfile)
 
         # check behaviour when writing to file without proper permission
         testfile = "tmp_testfile.write.BUFR"
         if os.path.exists(testfile):
             # force the file to be readwrite
-            os.chmod(testfile, 0666)
+            os.chmod(testfile, 0o666)
             os.remove(testfile)
 
         # create a small dummy fle
@@ -624,14 +624,14 @@ class CheckRawBUFRFile(unittest.TestCase):
         fdescr.write('dummy data')
         fdescr.close()
         # force the file to be readonly
-        os.chmod(testfile, 0444)
+        os.chmod(testfile, 0o444)
         # do the test
         self.assertRaises(IOError, bufrfile.open, testfile, 'wb',
                           silent=True)
         # cleanup
         if os.path.exists(testfile):
             # force the file to be readwrite
-            os.chmod(testfile, 0666)
+            os.chmod(testfile, 0o666)
             os.remove(testfile)
         #  #]
     def test_close(self):
